==> bat-0.25.0.tar.gz: bat-0.25.0/tests/syntax-tests/highlighted/Java/test.java <==
[38;2;249;38;114mimport[0m[38;2;248;248;242m [0m[3;38;2;166;226;46mjava[0m[38;2;248;248;242m.[0m[3;38;2;166;226;46mutil[0m[38;2;248;248;242m.[0m[3;38;2;166;226;46mScanner[0m[38;2;248;248;242m;[0m

[38;2;117;113;94m/*[0m[38;2;117;113;94m This Java program was submiited to help bat[0m
[38;2;117;113;94m * with its syntax highlighting tests[0m
[38;2;117;113;94m [0m[38;2;117;113;94m*/[0m

[38;2;249;38;114mpublic[0m[38;2;248;248;242m [0m[3;38;2;102;217;239mclass[0m[38;2;248;248;242m [0m[4;38;2;102;217;239mMain[0m
[38;2;248;248;242m{[0m
[38;2;248;248;242m    [0m[38;2;249;38;114mpublic[0m[38;2;248;248;242m [0m[38;2;249;38;114mstatic[0m[38;2;248;248;242m [0m[3;38;2;102;217;239mvoid[0m[38;2;248;248;242m [0m[38;2;166;226;46mmain[0m[38;2;248;248;242m([0m[3;38;2;166;226;46mString[0m[38;2;249;38;114m[][0m[38;2;248;248;242m [0m[3;38;2;253;151;31marg[0m[38;2;248;248;242m)[0m
[38;2;248;248;242m    [0m[38;2;248;248;242m{[0m
[38;2;248;248;242m        [0m[3;38;2;166;226;46mScanner[0m[38;2;248;248;242m st [0m[38;2;249;38;114m=[0m[38;2;248;248;242m [0m[38;2;249;38;114mnew[0m[38;2;248;248;242m [0m[3;38;2;166;226;46mScanner[0m[38;2;248;248;242m([0m[3;38;2;166;226;46mSystem[0m[38;2;248;248;242m.[0m[38;2;248;248;242min[0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        [0m[3;38;2;102;217;239mint[0m[38;2;248;248;242m t[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        t [0m[38;2;249;38;114m=[0m[38;2;248;248;242m st[0m[38;2;248;248;242m.[0m[38;2;248;248;242mnextInt[0m[38;2;248;248;242m([0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        [0m[3;38;2;166;226;46mString[0m[38;2;248;248;242m tem[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        tem [0m[38;2;249;38;114m=[0m[38;2;248;248;242m st[0m[38;2;248;248;242m.[0m[38;2;248;248;242mnextLine[0m[38;2;248;248;242m([0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        [0m[38;2;249;38;114mfor[0m[38;2;248;248;242m([0m[3;38;2;102;217;239mint[0m[38;2;248;248;242m zz[0m[38;2;249;38;114m=[0m[38;2;190;132;255m0[0m[38;2;248;248;242m;[0m[38;2;248;248;242mzz[0m[38;2;249;38;114m<[0m[38;2;248;248;242mt[0m[38;2;248;248;242m;[0m[38;2;248;248;242mzz[0m[38;2;249;38;114m++[0m[38;2;248;248;242m)[0m
[38;2;248;248;242m        [0m[38;2;248;248;242m{[0m
[38;2;248;248;242m            [0m[3;38;2;166;226;46mString[0m[38;2;248;248;242m str[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m            str [0m[38;2;249;38;114m=[0m[38;2;248;248;242m st[0m[38;2;248;248;242m.[0m[38;2;248;248;242mnextLine[0m[38;2;248;248;242m([0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m            [0m[3;38;2;102;217;239mint[0m[38;2;248;248;242m n [0m[38;2;249;38;114m=[0m[38;2;248;248;242m str[0m[38;2;248;248;242m.[0m[38;2;248;248;242mlength[0m[38;2;248;248;242m([0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m            [0m[3;38;2;102;217;239mchar[0m[38;2;248;248;242m ch[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m            [0m[38;2;249;38;114mfor[0m[38;2;248;248;242m([0m[3;38;2;102;217;239mint[0m[38;2;248;248;242m i[0m[38;2;249;38;114m=[0m[38;2;190;132;255m0[0m[38;2;248;248;242m;[0m[38;2;248;248;242mi[0m[38;2;249;38;114m<[0m[38;2;248;248;242mn[0m[38;2;248;248;242m;[0m[38;2;248;248;242mi[0m[38;2;249;38;114m++[0m[38;2;248;248;242m)[0m
[38;2;248;248;242m            [0m[38;2;248;248;242m{[0m
[38;2;248;248;242m                ch [0m[38;2;249;38;114m=[0m[38;2;248;248;242m str[0m[38;2;248;248;242m.[0m[38;2;248;248;242mcharAt[0m[38;2;248;248;242m([0m[38;2;248;248;242mi[0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m                [0m[38;2;249;38;114mif[0m[38;2;248;248;242m([0m[38;2;248;248;242mch[0m[38;2;249;38;114m==[0m[38;2;230;219;116m'[0m[38;2;230;219;116ma[0m[38;2;230;219;116m'[0m[38;2;248;248;242m)[0m
[38;2;248;248;242m                [0m[3;38;2;166;226;46mSystem[0m[38;2;248;248;242m.[0m[38;2;248;248;242mout[0m[38;2;248;248;242m.[0m[38;2;248;248;242mprint[0m[38;2;248;248;242m([0m[38;2;230;219;116m"[0m[38;2;230;219;116mn[0m[38;2;230;219;116m"[0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m                [0m[38;2;249;38;114melse[0m[38;2;248;248;242m [0m[38;2;249;38;114mif[0m[38;2;248;248;242m([0m[38;2;248;248;242mch[0m[38;2;249;38;114m==[0m[38;2;230;219;116m'[0m[38;2;230;219;116ms[0m[38;2;230;219;116m'[0m[38;2;248;248;242m)[0m
[38;2;248;248;242m                [0m[3;38;2;166;226;46mSystem[0m[38;2;248;248;242m.[0m[38;2;248;248;242mout[0m[38;2;248;248;242m.[0m[38;2;248;248;242mprint[0m[38;2;248;248;242m([0m[38;2;230;219;116m"[0m[38;2;230;219;116mi[0m[38;2;230;219;116m"[0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m                [0m[38;2;249;38;114melse[0m
[38;2;248;248;242m                [0m[3;38;2;166;226;46mSystem[0m[38;2;248;248;242m.[0m[38;2;248;248;242mout[0m[38;2;248;248;242m.[0m[38;2;248;248;242mprint[0m[38;2;248;248;242m([0m[38;2;248;248;242mch[0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m            [0m[38;2;248;248;242m}[0m
[38;2;248;248;242m            [0m[3;38;2;166;226;46mSystem[0m[38;2;248;248;242m.[0m[38;2;248;248;242mout[0m[38;2;248;248;242m.[0m[38;2;248;248;242mprintln[0m[38;2;248;248;242m([0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        [0m[38;2;248;248;242m}[0m
[38;2;248;248;242m        [0m[38;2;249;38;114mwhile[0m[38;2;248;248;242m([0m[38;2;248;248;242mt[0m[38;2;249;38;114m!=[0m[38;2;190;132;255m0[0m[38;2;248;248;242m)[0m[38;2;248;248;242m [0m[38;2;248;248;242m{[0m
[38;2;248;248;242m            [0m[38;2;117;113;94m//[0m[38;2;117;113;94m Decrement t[0m
[38;2;248;248;242m            t [0m[38;2;249;38;114m-=[0m[38;2;248;248;242m [0m[38;2;190;132;255m1[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        [0m[38;2;248;248;242m}[0m
[38;2;248;248;242m    [0m[38;2;248;248;242m}[0m
[38;2;248;248;242m}[0m

==> bat-0.26.0.tar.gz: bat-0.26.0/tests/syntax-tests/highlighted/Java/test.java <==
[38;2;249;38;114mimport[0m[38;2;248;248;242m [0m[3;38;2;166;226;46mjava[0m[38;2;248;248;242m.[0m[3;38;2;166;226;46mutil[0m[38;2;248;248;242m.[0m[3;38;2;166;226;46mScanner[0m[38;2;248;248;242m;[0m

[38;2;117;113;94m/*[0m[38;2;117;113;94m This Java program was submitted to help bat[0m
[38;2;117;113;94m * with its syntax highlighting tests[0m
[38;2;117;113;94m [0m[38;2;117;113;94m*/[0m

[38;2;249;38;114mpublic[0m[38;2;248;248;242m [0m[3;38;2;102;217;239mclass[0m[38;2;248;248;242m [0m[4;38;2;102;217;239mMain[0m
[38;2;248;248;242m{[0m
[38;2;248;248;242m    [0m[38;2;249;38;114mpublic[0m[38;2;248;248;242m [0m[38;2;249;38;114mstatic[0m[38;2;248;248;242m [0m[3;38;2;102;217;239mvoid[0m[38;2;248;248;242m [0m[38;2;166;226;46mmain[0m[38;2;248;248;242m([0m[3;38;2;166;226;46mString[0m[38;2;249;38;114m[][0m[38;2;248;248;242m [0m[3;38;2;253;151;31marg[0m[38;2;248;248;242m)[0m
[38;2;248;248;242m    [0m[38;2;248;248;242m{[0m
[38;2;248;248;242m        [0m[3;38;2;166;226;46mScanner[0m[38;2;248;248;242m st [0m[38;2;249;38;114m=[0m[38;2;248;248;242m [0m[38;2;249;38;114mnew[0m[38;2;248;248;242m [0m[3;38;2;166;226;46mScanner[0m[38;2;248;248;242m([0m[3;38;2;166;226;46mSystem[0m[38;2;248;248;242m.[0m[38;2;248;248;242min[0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        [0m[3;38;2;102;217;239mint[0m[38;2;248;248;242m t[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        t [0m[38;2;249;38;114m=[0m[38;2;248;248;242m st[0m[38;2;248;248;242m.[0m[38;2;248;248;242mnextInt[0m[38;2;248;248;242m([0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        [0m[3;38;2;166;226;46mString[0m[38;2;248;248;242m tem[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        tem [0m[38;2;249;38;114m=[0m[38;2;248;248;242m st[0m[38;2;248;248;242m.[0m[38;2;248;248;242mnextLine[0m[38;2;248;248;242m([0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        [0m[38;2;249;38;114mfor[0m[38;2;248;248;242m([0m[3;38;2;102;217;239mint[0m[38;2;248;248;242m zz[0m[38;2;249;38;114m=[0m[38;2;190;132;255m0[0m[38;2;248;248;242m;[0m[38;2;248;248;242mzz[0m[38;2;249;38;114m<[0m[38;2;248;248;242mt[0m[38;2;248;248;242m;[0m[38;2;248;248;242mzz[0m[38;2;249;38;114m++[0m[38;2;248;248;242m)[0m
[38;2;248;248;242m        [0m[38;2;248;248;242m{[0m
[38;2;248;248;242m            [0m[3;38;2;166;226;46mString[0m[38;2;248;248;242m str[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m            str [0m[38;2;249;38;114m=[0m[38;2;248;248;242m st[0m[38;2;248;248;242m.[0m[38;2;248;248;242mnextLine[0m[38;2;248;248;242m([0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m            [0m[3;38;2;102;217;239mint[0m[38;2;248;248;242m n [0m[38;2;249;38;114m=[0m[38;2;248;248;242m str[0m[38;2;248;248;242m.[0m[38;2;248;248;242mlength[0m[38;2;248;248;242m([0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m            [0m[3;38;2;102;217;239mchar[0m[38;2;248;248;242m ch[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m            [0m[38;2;249;38;114mfor[0m[38;2;248;248;242m([0m[3;38;2;102;217;239mint[0m[38;2;248;248;242m i[0m[38;2;249;38;114m=[0m[38;2;190;132;255m0[0m[38;2;248;248;242m;[0m[38;2;248;248;242mi[0m[38;2;249;38;114m<[0m[38;2;248;248;242mn[0m[38;2;248;248;242m;[0m[38;2;248;248;242mi[0m[38;2;249;38;114m++[0m[38;2;248;248;242m)[0m
[38;2;248;248;242m            [0m[38;2;248;248;242m{[0m
[38;2;248;248;242m                ch [0m[38;2;249;38;114m=[0m[38;2;248;248;242m str[0m[38;2;248;248;242m.[0m[38;2;248;248;242mcharAt[0m[38;2;248;248;242m([0m[38;2;248;248;242mi[0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m                [0m[38;2;249;38;114mif[0m[38;2;248;248;242m([0m[38;2;248;248;242mch[0m[38;2;249;38;114m==[0m[38;2;230;219;116m'[0m[38;2;230;219;116ma[0m[38;2;230;219;116m'[0m[38;2;248;248;242m)[0m
[38;2;248;248;242m                [0m[3;38;2;166;226;46mSystem[0m[38;2;248;248;242m.[0m[38;2;248;248;242mout[0m[38;2;248;248;242m.[0m[38;2;248;248;242mprint[0m[38;2;248;248;242m([0m[38;2;230;219;116m"[0m[38;2;230;219;116mn[0m[38;2;230;219;116m"[0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m                [0m[38;2;249;38;114melse[0m[38;2;248;248;242m [0m[38;2;249;38;114mif[0m[38;2;248;248;242m([0m[38;2;248;248;242mch[0m[38;2;249;38;114m==[0m[38;2;230;219;116m'[0m[38;2;230;219;116ms[0m[38;2;230;219;116m'[0m[38;2;248;248;242m)[0m
[38;2;248;248;242m                [0m[3;38;2;166;226;46mSystem[0m[38;2;248;248;242m.[0m[38;2;248;248;242mout[0m[38;2;248;248;242m.[0m[38;2;248;248;242mprint[0m[38;2;248;248;242m([0m[38;2;230;219;116m"[0m[38;2;230;219;116mi[0m[38;2;230;219;116m"[0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m                [0m[38;2;249;38;114melse[0m
[38;2;248;248;242m                [0m[3;38;2;166;226;46mSystem[0m[38;2;248;248;242m.[0m[38;2;248;248;242mout[0m[38;2;248;248;242m.[0m[38;2;248;248;242mprint[0m[38;2;248;248;242m([0m[38;2;248;248;242mch[0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m            [0m[38;2;248;248;242m}[0m
[38;2;248;248;242m            [0m[3;38;2;166;226;46mSystem[0m[38;2;248;248;242m.[0m[38;2;248;248;242mout[0m[38;2;248;248;242m.[0m[38;2;248;248;242mprintln[0m[38;2;248;248;242m([0m[38;2;248;248;242m)[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        [0m[38;2;248;248;242m}[0m
[38;2;248;248;242m        [0m[38;2;249;38;114mwhile[0m[38;2;248;248;242m([0m[38;2;248;248;242mt[0m[38;2;249;38;114m!=[0m[38;2;190;132;255m0[0m[38;2;248;248;242m)[0m[38;2;248;248;242m [0m[38;2;248;248;242m{[0m
[38;2;248;248;242m            [0m[38;2;117;113;94m//[0m[38;2;117;113;94m Decrement t[0m
[38;2;248;248;242m            t [0m[38;2;249;38;114m-=[0m[38;2;248;248;242m [0m[38;2;190;132;255m1[0m[38;2;248;248;242m;[0m
[38;2;248;248;242m        [0m[38;2;248;248;242m}[0m
[38;2;248;248;242m    [0m[38;2;248;248;242m}[0m
[38;2;248;248;242m}[0m
